MacCounters

Struct MacCounters 

pub struct MacCounters {
Show 26 fields pub total: Option<u32>, pub unicast: Option<u32>, pub broadcast: Option<u32>, pub ack_requested: Option<u32>, pub acked: Option<u32>, pub no_ack_requested: Option<u32>, pub data: Option<u32>, pub data_poll: Option<u32>, pub beacon: Option<u32>, pub beacon_request: Option<u32>, pub other: Option<u32>, pub address_filtered: Option<u32>, pub retries: Option<u32>, pub direct_max_retry_expiry: Option<u32>, pub indirect_max_retry_expiry: Option<u32>, pub dest_addr_filtered: Option<u32>, pub duplicated: Option<u32>, pub err_no_frame: Option<u32>, pub err_unknown_neighbor: Option<u32>, pub err_invalid_src_addr: Option<u32>, pub err_sec: Option<u32>, pub err_fcs: Option<u32>, pub err_cca: Option<u32>, pub err_abort: Option<u32>, pub err_busy_channel: Option<u32>, pub err_other: Option<u32>, /* private fields */
}
Counters associated with the MAC layer.

Some counters are only valid for RX or TX.

Fields

total: Option<u32>

The total number of frames

unicast: Option<u32>

The total number of unicast frames

broadcast: Option<u32>

The total number of broadcast frames

ack_requested: Option<u32>

The number of frames with ack request

acked: Option<u32>

The number of frames that were acked

no_ack_requested: Option<u32>

The number of frames without ack request

data: Option<u32>

The number of data frames

data_poll: Option<u32>

The number of data poll frames

beacon: Option<u32>

The number of beacon frames

beacon_request: Option<u32>

The number of beacon request frames

other: Option<u32>

The number of other types of frames

address_filtered: Option<u32>

The number of frames filtered by address filter (allowlist or denylist).

retries: Option<u32>

The number of retransmission attempts. TX only.

direct_max_retry_expiry: Option<u32>

The number of expired retransmission retries for direct message. TX only.

indirect_max_retry_expiry: Option<u32>

The number of expired retransmission retries for indirect message TX only.

dest_addr_filtered: Option<u32>

The number of received frames filtered by destination check. RX only.

duplicated: Option<u32>

The number of received duplicated frames. RX only.

err_no_frame: Option<u32>

The number of received frames with no or malformed content. RX only.

err_unknown_neighbor: Option<u32>

The number of received frames from unknown neighbor. RX only.

err_invalid_src_addr: Option<u32>

The number of received frames whose source address is invalid. RX only.

err_sec: Option<u32>

The number of received frames with security error. RX only.

err_fcs: Option<u32>

The number of received frames with FCS error. RX only.

err_cca: Option<u32>

The number of CCA failures. TX only.

err_abort: Option<u32>

The number of frame transmission failures due to abort error. TX only.

err_busy_channel: Option<u32>

The number of frames that were dropped due to a busy channel. TX only.

err_other: Option<u32>

The number of frames that encountered some other error.