MleCounters

Struct MleCounters 

pub struct MleCounters {
Show 16 fields pub disabled_role: Option<u16>, pub detached_role: Option<u16>, pub child_role: Option<u16>, pub router_role: Option<u16>, pub leader_role: Option<u16>, pub attach_attempts: Option<u16>, pub partition_id_changes: Option<u16>, pub better_partition_attach_attempts: Option<u16>, pub better_parent_attach_attempts: Option<u16>, pub disabled_time: Option<u64>, pub detached_time: Option<u64>, pub child_time: Option<u64>, pub router_time: Option<u64>, pub leader_time: Option<u64>, pub tracked_time: Option<u64>, pub parent_changes: Option<u16>, /* private fields */
}
Counters associated with the MLE.

Fields

disabled_role: Option<u16>

Number of times device entered OT_DEVICE_ROLE_DISABLED role.

detached_role: Option<u16>

Number of times device entered OT_DEVICE_ROLE_DETACHED role.

child_role: Option<u16>

Number of times device entered OT_DEVICE_ROLE_CHILD role.

router_role: Option<u16>

Number of times device entered OT_DEVICE_ROLE_ROUTER role.

leader_role: Option<u16>

Number of times device entered OT_DEVICE_ROLE_LEADER role.

attach_attempts: Option<u16>

Number of attach attempts while device was detached.

partition_id_changes: Option<u16>

Number of changes to partition ID.

better_partition_attach_attempts: Option<u16>

Number of attempts to attach to a better partition.

better_parent_attach_attempts: Option<u16>

Number of attempts to attach to find a better parent (parent search).

disabled_time: Option<u64>

Number of milliseconds device has been in OT_DEVICE_ROLE_DISABLED role.

detached_time: Option<u64>

Number of milliseconds device has been in OT_DEVICE_ROLE_DETACHED role.

child_time: Option<u64>

Number of milliseconds device has been in OT_DEVICE_ROLE_CHILD role.

router_time: Option<u64>

Number of milliseconds device has been in OT_DEVICE_ROLE_ROUTER role.

leader_time: Option<u64>

Number of milliseconds device has been in OT_DEVICE_ROLE_LEADER role.

tracked_time: Option<u64>

Number of milliseconds tracked by previous counters.

parent_changes: Option<u16>

Number of times device changed its parent.